@@ -1,5 +1,9 @@
 #include "Profiler.h"
 
+#ifdef _WIN32
+// need to undef ERROR to avoid redefinition between R and Windows gdi.h
+#undef ERROR
+#endif
 #include <R.h>
 
 #include <vector>
@@ -7,7 +11,7 @@
 
 #include "SimpleTimer.h"
 
-std::unordered_map<std::string, Profiler::Metric> Profiler::data;
+std::map<std::string, Profiler::Metric> Profiler::data;
 
 void Profiler::addTimer(const char* func) {
   Metric& m = data[func];
@@ -33,16 +37,23 @@ struct FlatMetric{
   double totalElapsed;
 };
 
+struct FlatMetricCompare{
+  bool operator()(const FlatMetric& a, const FlatMetric& b) {
+    return a.avgElapsed > b.avgElapsed;
+  }
+} flatMetricCompare;
+
+
 void Profiler::dump() {
   std::vector< FlatMetric > v;
-  for (auto& x : Profiler::data) {
-    v.push_back(FlatMetric(x.first, x.second.nHits, x.second.timer.getSeconds()));
+  for (std::map<std::string, Metric>::iterator it = data.begin();
+       it != data.end();
+       ++it) {
+    v.push_back(FlatMetric(it->first, it->second.nHits, it->second.timer.getSeconds()));
   }
-  std::sort(v.begin(), v.end(),
-            [](const FlatMetric& a, const FlatMetric& b) -> bool {
-              return a.avgElapsed > b.avgElapsed;
-            });
-  for (auto& x: v) {
+  std::sort(v.begin(), v.end(), flatMetricCompare);
+  for (size_t i = 0; i != v.size(); ++i) {
+    const FlatMetric& x = v[i];
     REprintf(
         "Function [ %s ] hit [ %d ] times, total elapsed time [ %g ] seconds, avg elapsed time [ %g ] seconds\n",
         x.func.c_str(), x.nHits, x.totalElapsed, x.avgElapsed);
