@@ -12,7 +12,7 @@ void extractString(SEXP in, std::string* out) {
 void extractStringArray(SEXP in, std::vector<std::string>* out) {
   out->clear();
   std::string s;
-  for (R_len_t i = 0; i < length(in); i++) {
+  for (R_len_t i = 0; i < LENGTH(in); i++) {
     s = CHAR(STRING_ELT(in, i));
     if (s.size()) {
       out->push_back(s);
@@ -23,14 +23,14 @@ void extractStringArray(SEXP in, std::vector<std::string>* out) {
 
 void extractIntArray(SEXP in, std::vector<int>* out) {
   out->clear();
-  for (R_len_t i = 0; i < length(in); i++) {
+  for (R_len_t i = 0; i < LENGTH(in); i++) {
     out->push_back(INTEGER(in)[i]);
   }
 }
 
 void extractStringSet(SEXP in, std::set<std::string>* out) {
   std::string s;
-  for (R_len_t i = 0; i < length(in); i++) {
+  for (R_len_t i = 0; i < LENGTH(in); i++) {
     s = CHAR(STRING_ELT(in, i));
     out->insert(s);
     // Rprintf("extractStringArray: [%d] %s\n", out->size(), s.c_str());
@@ -40,8 +40,8 @@ void extractStringSet(SEXP in, std::set<std::string>* out) {
 /* get the list element named str, or return NULL */
 SEXP getListElement(SEXP list, const char* str) {
   SEXP elmt = R_NilValue;
-  SEXP names = getAttrib(list, R_NamesSymbol);
-  for (R_len_t i = 0; i < length(list); i++)
+  SEXP names = Rf_getAttrib(list, R_NamesSymbol);
+  for (R_len_t i = 0; i < LENGTH(list); i++)
     if (std::strcmp(CHAR(STRING_ELT(names, i)), str) == 0) {
       elmt = VECTOR_ELT(list, i);
       break;
@@ -63,7 +63,7 @@ void dump(std::vector<std::string>& s) {
 void storeResult(const std::vector<bool>& in, SEXP& ret, int idx) {
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = in.size();
-  PROTECT(s = allocVector(LGLSXP, n));
+  PROTECT(s = Rf_allocVector(LGLSXP, n));
   for (int i = 0; i < n; ++i) {
     LOGICAL(s)[i] = in[i];
   }
@@ -74,7 +74,7 @@ void storeResult(const std::vector<bool>& in, SEXP& ret, int idx) {
 void storeResult(const std::vector<int>& in, SEXP& ret, int idx) {
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = in.size();
-  PROTECT(s = allocVector(INTSXP, n));
+  PROTECT(s = Rf_allocVector(INTSXP, n));
   for (int i = 0; i < n; ++i) {
     INTEGER(s)[i] = in[i];
   }
@@ -85,9 +85,9 @@ void storeResult(const std::vector<int>& in, SEXP& ret, int idx) {
 void storeResult(const std::vector<std::string>& in, SEXP ret, int idx) {
   SEXP s;  //  = VECTOR_ELT(ret, i);
   int n = in.size();
-  PROTECT(s = allocVector(STRSXP, n));
+  PROTECT(s = Rf_allocVector(STRSXP, n));
   for (int i = 0; i < n; ++i) {
-    SET_STRING_ELT(s, i, mkChar(in[i].c_str()));
+    SET_STRING_ELT(s, i, Rf_mkChar(in[i].c_str()));
     // Rprintf("storeResult [%d] = %s\n", i, in[i].c_str());
   }
   SET_VECTOR_ELT(ret, idx, s);
@@ -97,7 +97,7 @@ void storeResult(const std::vector<std::string>& in, SEXP ret, int idx) {
 void storeResult(const std::vector<double>& in, SEXP& ret, int idx) {
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = in.size();
-  PROTECT(s = allocVector(REALSXP, n));
+  PROTECT(s = Rf_allocVector(REALSXP, n));
   for (int i = 0; i < n; ++i) {
     REAL(s)[i] = in[i];
   }
@@ -109,7 +109,7 @@ void storeIntResult(const std::vector<std::string>& in, SEXP& ret, int idx) {
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = in.size();
   int tmp;
-  PROTECT(s = allocVector(INTSXP, n));
+  PROTECT(s = Rf_allocVector(INTSXP, n));
   for (int i = 0; i < n; ++i) {
     if (str2int(in[i], &tmp))
       INTEGER(s)[i] = tmp;
@@ -124,7 +124,7 @@ void storeDoubleResult(const std::vector<std::string>& in, SEXP& ret, int idx) {
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = in.size();
   double tmp;
-  PROTECT(s = allocVector(REALSXP, n));
+  PROTECT(s = Rf_allocVector(REALSXP, n));
   for (int i = 0; i < n; ++i) {
     if (str2double(in[i], &tmp))
       REAL(s)[i] = tmp;
@@ -140,7 +140,7 @@ void storeResult(const std::vector<std::vector<double> >& in, SEXP& ret,
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = in.size();
   int numAllocated = 0;
-  PROTECT(s = allocVector(VECSXP, n));
+  PROTECT(s = Rf_allocVector(VECSXP, n));
   numAllocated++;
   for (int i = 0; i < n; ++i) {
     SEXP si;
@@ -156,7 +156,7 @@ void storeResult(const std::vector<std::vector<std::vector<double> > >& in,
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = in.size();
   int numAllocated = 0;
-  PROTECT(s = allocVector(VECSXP, n));
+  PROTECT(s = Rf_allocVector(VECSXP, n));
   numAllocated++;
   for (int i = 0; i < n; ++i) {
     SEXP si;
@@ -171,9 +171,9 @@ void storeResult(const std::string& key, const std::vector<std::string>& val,
                  SEXP ret, int idx) {
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = val.size();
-  PROTECT(s = allocVector(STRSXP, n));
+  PROTECT(s = Rf_allocVector(STRSXP, n));
   for (int i = 0; i < n; ++i) {
-    SET_STRING_ELT(s, i, mkChar(val[i].c_str()));
+    SET_STRING_ELT(s, i, Rf_mkChar(val[i].c_str()));
   }
   SET_VECTOR_ELT(ret, idx, s);
   UNPROTECT(1);
@@ -183,7 +183,7 @@ void storeResult(const std::string& key, const std::vector<int>& val, SEXP& ret,
                  int idx) {
   SEXP s;  // = VECTOR_ELT(ret, i);
   int n = val.size();
-  PROTECT(s = allocVector(INTSXP, n));
+  PROTECT(s = Rf_allocVector(INTSXP, n));
   for (int i = 0; i < n; ++i) {
     INTEGER(s)[i] = val[i];
   }
@@ -193,20 +193,20 @@ void storeResult(const std::string& key, const std::vector<int>& val, SEXP& ret,
 
 void setDim(int nrow, int ncol, SEXP s) {
   SEXP dim;
-  PROTECT(dim = allocVector(INTSXP, 2));
+  PROTECT(dim = Rf_allocVector(INTSXP, 2));
   INTEGER(dim)[0] = nrow;
   INTEGER(dim)[1] = ncol;
-  setAttrib(s, R_DimSymbol, dim);
+  Rf_setAttrib(s, R_DimSymbol, dim);
   UNPROTECT(1);
 }
 
 void setDim(int i, int j, int k, SEXP s) {
   SEXP dim;
-  PROTECT(dim = allocVector(INTSXP, 3));
+  PROTECT(dim = Rf_allocVector(INTSXP, 3));
   INTEGER(dim)[0] = i;
   INTEGER(dim)[1] = j;
   INTEGER(dim)[2] = k;
-  setAttrib(s, R_DimSymbol, dim);
+  Rf_setAttrib(s, R_DimSymbol, dim);
   UNPROTECT(1);
 }
 
@@ -223,12 +223,12 @@ void setDimNames(const std::vector<std::string>& nrow,
                  const std::vector<std::string>& ncol, SEXP s) {
   int numAllocated = 0;
   SEXP dimnames;
-  PROTECT(dimnames = allocVector(VECSXP, 2));
+  PROTECT(dimnames = Rf_allocVector(VECSXP, 2));
   ++numAllocated;
 
   storeResult(nrow, dimnames, 0);
   storeResult(ncol, dimnames, 1);
-  setAttrib(s, R_DimNamesSymbol, dimnames);
+  Rf_setAttrib(s, R_DimNamesSymbol, dimnames);
   UNPROTECT(numAllocated);
 }
 
@@ -237,82 +237,82 @@ void setDimNames(const std::vector<std::string>& ni,
                  const std::vector<std::string>& nk, SEXP s) {
   int numAllocated = 0;
   SEXP dimnames;
-  PROTECT(dimnames = allocVector(VECSXP, 3));
+  PROTECT(dimnames = Rf_allocVector(VECSXP, 3));
   ++numAllocated;
 
   storeResult(ni, dimnames, 0);
   storeResult(nj, dimnames, 1);
   storeResult(nk, dimnames, 2);
-  setAttrib(s, R_DimNamesSymbol, dimnames);
+  Rf_setAttrib(s, R_DimNamesSymbol, dimnames);
 
   UNPROTECT(numAllocated);
 }
 
 #if 0
 int createList(int n, SEXP* s) {
-  PROTECT((*s) = allocVector(VECSXP, n));
+  PROTECT((*s) = Rf_allocVector(VECSXP, n));
   return 1;
 }
 
 int createStringArray(int n, SEXP* s) {
-  PROTECT((*s) = allocVector(STRSXP, n));
+  PROTECT((*s) = Rf_allocVector(STRSXP, n));
   return 1;
 }
 
 int createDoubleArray(int n, SEXP* s) {
-  PROTECT((*s) = allocVector(REALSXP, n));
+  PROTECT((*s) = Rf_allocVector(REALSXP, n));
   return 1;
 }
 
 int createIntArray(int n, SEXP* s) {
-  PROTECT((*s) = allocVector(INTSXP, n));
+  PROTECT((*s) = Rf_allocVector(INTSXP, n));
   return 1;
 }
 #endif
 
 void setListNames(std::vector<std::string>& names, SEXP* s) {
   SEXP sListNames;
-  PROTECT(sListNames = allocVector(STRSXP, names.size()));
+  PROTECT(sListNames = Rf_allocVector(STRSXP, names.size()));
   for (unsigned int i = 0; i != names.size(); ++i) {
-    SET_STRING_ELT(sListNames, i, mkChar(names[i].c_str()));
+    SET_STRING_ELT(sListNames, i, Rf_mkChar(names[i].c_str()));
   }
-  setAttrib((*s), R_NamesSymbol, sListNames);
+  Rf_setAttrib((*s), R_NamesSymbol, sListNames);
   UNPROTECT(1);
 }
 
 void initDoubleArray(SEXP s) {
   double* r = REAL(s);
-  for (int i = 0; i < length(s); i++) {
+  for (int i = 0; i < LENGTH(s); i++) {
     r[i] = NA_REAL;
   }
 }
 
 void initIntArray(SEXP s) {
   int* r = INTEGER(s);
-  for (int i = 0; i < length(s); i++) {
+  for (int i = 0; i < LENGTH(s); i++) {
     r[i] = NA_INTEGER;
   }
 }
 
 void initStringArray(SEXP s) {
-  for (int i = 0; i < length(s); i++) {
+  for (int i = 0; i < LENGTH(s); i++) {
     SET_STRING_ELT(s, i, NA_STRING);
   }
 }
 
 void storeResult(const std::vector<std::string>& in, SEXP* ret) {
   int alloc = 0;
-  PROTECT((*ret) = allocVector(STRSXP, in.size()));
+  PROTECT((*ret) = Rf_allocVector(STRSXP, in.size()));
   alloc++;
   for (size_t i = 0; i < in.size(); ++i) {
-    SET_STRING_ELT((*ret), i, mkChar(in[i].c_str()));
+    SET_STRING_ELT((*ret), i, Rf_mkChar(in[i].c_str()));
   }
   UNPROTECT(alloc);
 }
 
 void storeResult(const std::vector<double>& in, SEXP* ret) {
   int alloc = 0;
-  PROTECT((*ret) = allocVector(REALSXP, in.size()));
+  PROTECT((*ret) = Rf_allocVector(REALSXP, in.size()));
   alloc++;
   for (size_t i = 0; i < in.size(); ++i) {
     REAL(*ret)[i] = in[i];
@@ -322,7 +322,7 @@ void storeResult(const std::vector<double>& in, SEXP* ret) {
 
 void storeResult(const std::vector<std::vector<double> >& in, SEXP* ret) {
   int alloc = 0;
-  PROTECT((*ret) = allocVector(VECSXP, in.size()));
+  PROTECT((*ret) = Rf_allocVector(VECSXP, in.size()));
   alloc++;
   for (size_t i = 0; i < in.size(); ++i) {
     SEXP si;
@@ -337,9 +337,9 @@ void storeResult(const std::vector<std::vector<double> >& in, SEXP* ret) {
  * @return 0 if success
  */
 int getDim(SEXP s, std::vector<int>* d) {
-  SEXP r = getAttrib(s, R_DimSymbol);
-  if (isNull(r)) return -1;
-  int n = length(r);
+  SEXP r = Rf_getAttrib(s, R_DimSymbol);
+  if (Rf_isNull(r)) return -1;
+  int n = LENGTH(r);
   d->resize(n);
   for (int i = 0; i < n; ++i) {
     (*d)[i] = INTEGER(r)[i];
