@@ -4,7 +4,7 @@
 #include <string>
 #include <vector>
 #include <map>
-#include <stdio.h>
+#include <cstdio>
 
 /**
  * For ANNO, support keywords are:
