@@ -58,7 +58,7 @@ SEXP readVCF2Matrix(VCFExtractor* vin) {
 
   SEXP ans = R_NilValue;
 
-  PROTECT(ans = allocMatrix(REALSXP, nx, ny));
+  PROTECT(ans = Rf_allocMatrix(REALSXP, nx, ny));
   double* rans = REAL(ans);
   int idx = 0;
   for (int i = 0; i < nx; i++) {
@@ -72,25 +72,25 @@ SEXP readVCF2Matrix(VCFExtractor* vin) {
 
   // set row and col names
   SEXP dim;
-  PROTECT(dim = allocVector(INTSXP, 2));
+  PROTECT(dim = Rf_allocVector(INTSXP, 2));
   INTEGER(dim)[0] = nx;
   INTEGER(dim)[1] = ny;
-  setAttrib(ans, R_DimSymbol, dim);
+  Rf_setAttrib(ans, R_DimSymbol, dim);
 
   SEXP rowName;
-  PROTECT(rowName = allocVector(STRSXP, nx));
+  PROTECT(rowName = Rf_allocVector(STRSXP, nx));
   for (int i = 0; i < nx; i++)
-    SET_STRING_ELT(rowName, i, mkChar(posVec[i].c_str()));
+    SET_STRING_ELT(rowName, i, Rf_mkChar(posVec[i].c_str()));
   SEXP colName;
-  PROTECT(colName = allocVector(STRSXP, ny));
+  PROTECT(colName = Rf_allocVector(STRSXP, ny));
   for (int i = 0; i < ny; i++)
-    SET_STRING_ELT(colName, i, mkChar(idVec[i].c_str()));
+    SET_STRING_ELT(colName, i, Rf_mkChar(idVec[i].c_str()));
 
   SEXP dimnames;
-  PROTECT(dimnames = allocVector(VECSXP, 2));
+  PROTECT(dimnames = Rf_allocVector(VECSXP, 2));
   SET_VECTOR_ELT(dimnames, 0, rowName);
   SET_VECTOR_ELT(dimnames, 1, colName);
-  setAttrib(ans, R_DimNamesSymbol, dimnames);
+  Rf_setAttrib(ans, R_DimNamesSymbol, dimnames);
 
   // finish up
   UNPROTECT(5);
@@ -135,11 +135,11 @@ SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range,
   std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType, 0));
 
   if (FLAG_fileName.size() == 0) {
-    error("Please provide VCF file name");
+    Rf_error("Please provide VCF file name");
     return ans;
   }
   if (FLAG_range.empty()) {
-    error("Please provide a given range, e.g. '1:100-200'");
+    Rf_error("Please provide a given range, e.g. '1:100-200'");
     return ans;
   }
 
@@ -156,7 +156,7 @@ SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range,
   int numAllocated = 0;
 
   // allocate return value
-  PROTECT(ans = allocVector(VECSXP, nGene));
+  PROTECT(ans = Rf_allocVector(VECSXP, nGene));
   numAllocated++;
   setListNames(FLAG_range, &ans);
 
@@ -194,10 +194,10 @@ SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile,
   std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType, 0));
 
   if (FLAG_fileName.size() == 0) {
-    error("Please provide VCF file name");
+    Rf_error("Please provide VCF file name");
   }
   if (FLAG_geneName.size() && FLAG_geneFile.size() == 0) {
-    error("Please provide gene file name when extract genotype by gene");
+    Rf_error("Please provide gene file name when extract genotype by gene");
   }
   if (!FLAG_annoType.empty() && !vcfHasAnnotation(FLAG_fileName)) {
     REprintf(
@@ -212,7 +212,7 @@ SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile,
   int numAllocated = 0;
 
   // allocate return value
-  PROTECT(ans = allocVector(VECSXP, nGene));
+  PROTECT(ans = Rf_allocVector(VECSXP, nGene));
   numAllocated++;
   setListNames(FLAG_geneName, &ans);
 
@@ -227,7 +227,7 @@ SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile,
     if (range.size())
       vin.setRangeList(range.c_str());
     else {
-      warning("Gene name [ %s ] does not exists in provided gene file",
+      Rf_warning("Gene name [ %s ] does not exists in provided gene file",
               FLAG_geneName[i].c_str());
       UNPROTECT(numAllocated);
       return (ans);
@@ -261,7 +261,7 @@ SEXP readVCF2List(VCFInputFile* vin,
   int numAllocated =
       0;  // record how many times we allocate (using PROTECT in R);
   SEXP ret;
-  PROTECT(ret = allocVector(VECSXP, retListLen));
+  PROTECT(ret = Rf_allocVector(VECSXP, retListLen));
   numAllocated++;
 
   //  store results
@@ -453,12 +453,12 @@ SEXP readVCF2List(VCFInputFile* vin,
 
   // Rprintf("set list names\n");
   SEXP sListNames;
-  PROTECT(sListNames = allocVector(STRSXP, listNames.size()));
+  PROTECT(sListNames = Rf_allocVector(STRSXP, listNames.size()));
   numAllocated++;
   for (unsigned int i = 0; i != listNames.size(); ++i) {
-    SET_STRING_ELT(sListNames, i, mkChar(listNames[i].c_str()));
+    SET_STRING_ELT(sListNames, i, Rf_mkChar(listNames[i].c_str()));
   }
-  setAttrib(ret, R_NamesSymbol, sListNames);
+  Rf_setAttrib(ret, R_NamesSymbol, sListNames);
 
   // finish up
   UNPROTECT(numAllocated);
@@ -497,7 +497,7 @@ SEXP impl_readVCFToListByRange(SEXP arg_fileName, SEXP arg_range,
   if (FLAG_range.size())
     vin.setRangeList(FLAG_range.c_str());
   else {
-    error("Please provide a range before we can continue.\n");
+    Rf_error("Please provide a range before we can continue.\n");
   };
   if (!FLAG_annoType.empty() && !vcfHasAnnotation(FLAG_fileName)) {
     REprintf(
@@ -579,7 +579,7 @@ SEXP impl_readVCFToListByGene(SEXP arg_fileName, SEXP arg_geneFile,
   if (range.size())
     vin.setRangeList(range.c_str());
   else {
-    error("Please provide a valid gene name before we can continue.\n");
+    Rf_error("Please provide a valid gene name before we can continue.\n");
   };
 
   if (FLAG_annoType.size()) {
